@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codepipeline._jsii
 import aws_cdk.aws_codepipeline_actions._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-codepipeline-check-parameter-action",
-    "1.1.9",
+    "1.1.11",
     __name__[0:-6],
-    "cdk-codepipeline-check-parameter-action@1.1.9.jsii.tgz",
+    "cdk-codepipeline-check-parameter-action@1.1.11.jsii.tgz",
 )
 
 __all__ = [
